<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Zoom</name>
    <message>
        <location filename="../Zoom.js" line="+51"/>
        <source>Zoom</source>
        <translation>Přiblížení</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Zoom Tools</source>
        <translation>Nástroje přiblížení</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show zoom tools</source>
        <translation>Zobrazit nástroje přiblížení</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Zoom</source>
        <translation>&amp;Přiblížení</translation>
    </message>
</context>
</TS>
